function dB = gettransferfn(audiofile, BinsHz)
% dB = gettransferfn(audiofile, BinsHz)
% Return a transfer function discretized to the bin center frequencies
% contained in BinHz.  The correct transfer function is selected based
% on the audiofile name.
% audiofile - file name
% BinsHz - desired frequency bin centers
%
% Assumes that the transfer_functions directory is in the same
% directory as this function.

[directory,fname] = fileparts(audiofile);

% Parse out project, site, and deployment to access transfer function
match = regexp(fname, ...
        '(?<project>[A-Z]+[^0-9])(?<deployment>[0-9]+)(?<site>[^_]*)?_.*', ...
        'names');
    
if isempty(match)
    error('Unable to determine transfer function from filename: %s', ...
        audiofile);
end

% Find where this function is located
tfdir = fileparts(which(mfilename));

% Verify root directory exists
root = fullfile(tfdir, 'transfer_functions');
if ~ exist(root, 'dir')
    error('Missing directory: ', root);
end

% Construct path to directory with transfer function
path = fullfile(root, match.project, ...
    sprintf('%s%s%s', match.project, match.deployment, match.site'));

% Find transfer function (only .tf file) and read it if available
files = dir(fullfile(path, '*.tf'));
if length(files) ~= 1
    error('Unable to find transfer fn or transfer fn ambiguous')
end
transferfnfile = fullfile(path, files(1).name);
fileH = fopen(transferfnfile, 'r');
if fileH == -1
    error('Unable to open transfer fn %s\n(corresponding to: %s)', ...
        transferfnfile, audiofile)
end
freqpower = textscan(fileH, '%f %f');  % freq <whitespace> dB format

% Resample to DFT resolution
dB = interp1(freqpower{1}, freqpower{2}, BinsHz, 'linear', 'extrap');

1;



